Introduction
============

GANGA GUI is the GUI (Graphical User Interface) front-end to GANGA_ allowing users not comfortable working at the console the choice to work in a graphical environment. It is developed with PyQt_ (Python-bindings to the Qt_ graphical toolkit) and is built on top of the GANGA GPI (GANGA Public Interface).

GANGA GUI not only allows the user to build a GANGA job, submit it (i.e. execute it) locally or to a selection of distributed systems (e.g. batch systems, the Grid) and subsequently retrieve the results, it also provides a customisable job monitoring window that keeps track of running jobs and their status, a job management facility to organise past jobs and quick-scripting tools to run favourite code snippets all within an integrated graphical environment.

.. _GANGA: http://ganga.web.cern.ch/ganga/
.. _PyQt: http://www.riverbankcomputing.co.uk/pyqt/index.php
.. _Qt: http://www.trolltech.com/products/qt/index.html